<?php
/**
 * wp_notes functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package wp_notes
 */

if ( ! defined( 'WP_NOTES_VERSION' ) ) {
	// Replace the version number of the theme on each release.
	define( 'WP_NOTES_VERSION', '1.0.1' );
}

if ( ! function_exists( 'wp_notes_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function wp_notes_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on wp_notes, use a find and replace
		 * to change 'wp-notes' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'wp-notes', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'menu-1' => __( 'Header Menu', 'wp-notes' ),
			'menu-2' => __( 'Footer Menu', 'wp-notes' ),
		) );


		/*
		 * Add image sizes
		 */
		add_image_size( "wp_notes_thumbnail_square_mobile", 140, 140, true );
		add_image_size( "wp_notes_thumbnail_square", 380, 380, true );
		add_image_size( "wp_notes_thumbnail_blog", 450, 300, true );
		add_image_size( "wp_notes_thumbnail_single", 700, 600, false );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
				'style',
				'script',
			)
		);

		// Set up the WordPress core custom background feature.
		add_theme_support(
			'custom-background',
			apply_filters(
				'wp_notes_custom_background_args',
				array(
					'default-color' => 'ffffff',
					'default-image' => '',
				)
			)
		);

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support(
			'custom-logo',
			array(
				'height'      => 62,
				'width'       => 250,
				'flex-width'  => true,
				'flex-height' => true,
			)
		);
	}
endif;
add_action( 'after_setup_theme', 'wp_notes_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
if ( ! function_exists( 'wp_notes_content_width' ) ) {
	function wp_notes_content_width() {
		$GLOBALS['content_width'] = apply_filters( 'wp_notes_content_width', 1248 );
	}
}
add_action( 'after_setup_theme', 'wp_notes_content_width', 0 );

/**
 * Enqueue scripts and styles.
 */
if ( ! function_exists( 'wp_notes_scripts' ) ) {
	function wp_notes_scripts() {
		wp_enqueue_style( 'wp_notes-style', get_template_directory_uri() . '/assets/css/main.css', array(), '1.0.1' );

		wp_enqueue_script( 'wp_notes-navigation',
			get_template_directory_uri() . '/assets/js/navigation.js',
			array(),
			WP_NOTES_VERSION,
			true );
		wp_enqueue_script( 'wp_notes-main-scripts',
			get_template_directory_uri() . '/assets/js/main.js',
			array(),
			WP_NOTES_VERSION,
			true );

		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}
	}
}
add_action( 'wp_enqueue_scripts', 'wp_notes_scripts' );

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';


/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Comments walker
 */
require get_template_directory() . '/classes/class_wp_notes_walker_comment.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load TGMPA file
 */
require_once get_template_directory() . '/inc/tgmpa/class-tgm-plugin-activation.php';
require_once get_template_directory() . '/inc/tgmpa-config.php';
